use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( examples lib script t xt ) );
__DATA__
Alders
Andreas
Arnfjörð
Attribute
Austin
Basic
Bjarmason
Black
Brandon
Chris
Dagfinn
Damien
Damyan
Dashes
Dave
Devin
Dieter
Doran
Drew
Etheridge
Fish
Florian
GLD
Getopt
Gordon
Goulah
Gregory
Hans
Hepler
Hinrik
Hunter
Ilmari
Inc
Infinity
Interactive
Irving
Ivanov
Jesse
John
Johnson
Johnston
Jonathan
Jose
Justin
Karen
Koenig
Kogman
Krotkine
König
Little
Luehrs
Luis
Mannsåker
Martinez
Meta
Michael
MooseX
Nelo
NoGetopt
Olaf
Onyiah
OptionTypeMap
Oschwald
Pearcey
Prather
ProcessedArgv
Ragwitz
Ricardo
Rolsky
Ryan
SIGNES
Schout
Shlomi
Sigurðsson
Stevan
Strict
Stuart
Swartz
Taylor
Todd
Tomas
Trait
Yuval
andk
autarch
avarab
blblack
bobtfish
chris
dhoss
dkrotkine
dmn
doy
drew
ether
goraxe
goschwald
hdp
hinrik
ilmari
irc
jgoulah
jlmartinez
justin
lib
mschout
nelo
nothingmuch
olaf
rafl
rjbs
ryan
saj_git
shlomif
stevan
swartz
thepler
Ævar
Örn
